==> http_requests-1.3.0.tar.gz: lib/http_requests.dart <==
// ignore_for_file: unnecessary_cast

library http_requests;

import 'dart:convert' as convert;
import 'package:http/http.dart' as http;

late http.Response _kresponse;
dynamic _url;
dynamic _param;

String headerCookies(Map<String, String> cookies) =>
    cookies.entries.map((e) => '${e.key}=${e.value}').join('; ');

/// An Class To Make Get or Post HTTP Request
class HttpRequests {
  static Future _def(var val) async {
    _kresponse = val;
    Response _kponse = Response();
    return _kponse;
  }

  /// An Method To Make Post HTTP Request
  /// Pass Url First Which Is Mandatory [ url like https://secanonm.in ] And You Can Pass header And Data Using dictionary or map
  static post(String url, {dynamic headers, dynamic data, int timeout=10}) async {
    _url = Uri.parse(url);
    _param = data ?? {};
    Map<String, String> tempHeader = {
      'User-Agent':
          'Mozilla/5.0 (Windows NT 10.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/99.0.7113.93'
    };
    Map<dynamic, dynamic> _head = headers ?? tempHeader;
    Map<String, String> _header = _head as Map<String, String>;
    
    http.Response response =
        await http.post(_url, body: _param, headers: _header).timeout(
            Duration(seconds: timeout),
  onTimeout: () {
    // Time has run out, do what you wanted to do.
    return http.Response('Error', 500);
  });
        
    return await _def(response);
  }

  /// An Method To Make Get HTTP Request
  /// Pass Url First Which Is Mandatory [ url like https://secanonm.in ] And You Can Pass Headers Using dictionary or map
  static get(String url, {dynamic headers,int timeout=10}) async {
    var _url = Uri.parse(url);
    Map<String, String> tempHeader = {
      'User-Agent':
          'Mozilla/5.0 (Windows NT 10.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/99.0.7113.93'
    };
    Map<dynamic, dynamic> _head = headers ?? tempHeader;

    Map<String, String> _header = _head as Map<String, String>;

    http.Response response = await http.get(_url, headers: _header).timeout(
            Duration(seconds: timeout),
  onTimeout: () {
    // Time has run out, do what you wanted to do.
    return http.Response('Error', 500);
  });
    return await _def(response);
  }
}

/// Simply Class To Handle Response
class Response {
  /// It's Is test function
  test() {
    return "test !";
  }

  /// Simply Return Response code
  bool get hasError =>
      (400 <= _kresponse.statusCode) && (_kresponse.statusCode < 600);

  /// It return success status of request ,if request is complete than it return true else return false
  bool get success => !hasError;

  /// It return HTTP status Code of response like 200 , 301, 502
  get status => _kresponse.statusCode;

  /// It return url which you pass
  String get url => _url;

  /// It return Content Type of response like json or text
  String get contentType => _kresponse.headers['content-type'] ?? "unknow";

  /// It return content of response
  String get content => convert.utf8.decode(bytes, allowMalformed: true);

  /// It return json response in format of Map { like in python dict }
  Map<String, dynamic> get json{
    Map<String, dynamic>  _helo =  convert.jsonDecode(_kresponse.body) as Map<String, dynamic>;
    return _helo;
  }
  /// It return response header in format of Map { like in python dict }
  get headers => _kresponse.headers as Map<String, dynamic>;

  /// It return content of response simply
  get response => _kresponse.body;

  /// It return content length of response simply
  get contentLength => _kresponse.contentLength;

  /// It return Redirection Status of response simply
  get isRedirect => _kresponse.isRedirect;

  /// It return bytes comprising the body of response
  List<int> get bytes => _kresponse.bodyBytes;

  /// It tell you HTTP Status Error if any
  void throwForStatus() {
    if (!success) {
      throw HTTPException(
          'Invalid HTTP status code ${_kresponse.statusCode} for url $url',
          _kresponse);
    }
  }
}

/// Class For HTTP ERROR Handling
class HTTPException implements Exception {
  final String message;
  final http.Response response;
  HTTPException(this.message, this.response);
}

==> http_requests-1.5.0.tar.gz: lib/http_requests.dart <==
// ignore_for_file: unnecessary_cast

library http_requests;

import 'dart:convert' as convert;
import 'package:http/http.dart' as http;

late http.Response _kresponse;
dynamic _url;
dynamic _param;

String headerCookies(Map<String, String> cookies) =>
    cookies.entries.map((e) => '${e.key}=${e.value}').join('; ');

/// An Class To Make Get or Post HTTP Request
class HttpRequests {
  static Future _def(var val) async {
    _kresponse = val;
    Response _kponse = Response();
    return _kponse;
  }

  /// An Method To Make Post HTTP Request
  /// Pass Url First Which Is Mandatory [ url like https://secanonm.in ] And You Can Pass header And Data Using dictionary or map
  static post(String url,
      {dynamic headers, dynamic data, int timeout = 10}) async {
    _url = Uri.parse(url);
    _param = data ?? {};
    Map<String, String> tempHeader = {
      'User-Agent':
          'Mozilla/5.0 (Windows NT 10.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/99.0.7113.93'
    };
    Map<dynamic, dynamic> _head = headers ?? tempHeader;
    Map<String, String> _header = _head as Map<String, String>;
    http.Response response;
    try {
      response = await http
          .post(_url, body: _param, headers: _header)
          .timeout(Duration(seconds: timeout), onTimeout: () {
        // Time has run out, do what you wanted to do.
        return http.Response('Error', 500);
      });
    } catch (e) {
      response = http.Response('Error', 500);
    }

    return await _def(response);
  }

  /// An Method To Make Get HTTP Request
  /// Pass Url First Which Is Mandatory [ url like https://secanonm.in ] And You Can Pass Headers Using dictionary or map
  static get(String url, {dynamic headers, int timeout = 10}) async {
    var _url = Uri.parse(url);
    Map<String, String> tempHeader = {
      'User-Agent':
          'Mozilla/5.0 (Windows NT 10.0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/99.0.7113.93'
    };
    Map<dynamic, dynamic> _head = headers ?? tempHeader;

    Map<String, String> _header = _head as Map<String, String>;

    http.Response response;
    try {
      response = await http
          .get(_url, headers: _header)
          .timeout(Duration(seconds: timeout), onTimeout: () {
        // Time has run out, do what you wanted to do.
        return http.Response('Error', 500);
      });
    } catch (e) {
      response = http.Response('Error', 500);
    }
    return await _def(response);
  }
}

/// Simply Class To Handle Response
class Response {
  /// It's Is test function
  test() {
    return "test !";
  }

  /// Simply Return Response code
  bool get hasError =>
      (400 <= _kresponse.statusCode) && (_kresponse.statusCode < 600);

  /// It return success status of request ,if request is complete than it return true else return false
  bool get success => !hasError;

  /// It return HTTP status Code of response like 200 , 301, 502
  get status => _kresponse.statusCode;

  /// It return url which you pass
  String get url => _url;

  /// It return Content Type of response like json or text
  String get contentType => _kresponse.headers['content-type'] ?? "unknow";

  /// It return content of response
  String get content => convert.utf8.decode(bytes, allowMalformed: true);

  /// It return json response in format of Map { like in python dict }
  Map<dynamic, dynamic> get json {
    Map<dynamic, dynamic> _helo;
    try {
      _helo = convert.jsonDecode(_kresponse.body) as Map<dynamic, dynamic>;
    } catch (e) {
      _helo = {"status": "failed"};
    }
    return _helo;
  }

  /// It return response header in format of Map { like in python dict }
  get headers => _kresponse.headers as Map<String, dynamic>;

  /// It return content of response simply
  get response => _kresponse.body;

  /// It return content length of response simply
  get contentLength => _kresponse.contentLength;

  /// It return Redirection Status of response simply
  get isRedirect => _kresponse.isRedirect;

  /// It return bytes comprising the body of response
  List<int> get bytes => _kresponse.bodyBytes;

  /// It tell you HTTP Status Error if any
  void throwForStatus() {
    if (!success) {
      throw HTTPException(
          'Invalid HTTP status code ${_kresponse.statusCode} for url $url',
          _kresponse);
    }
  }
}

/// Class For HTTP ERROR Handling
class HTTPException implements Exception {
  final String message;
  final http.Response response;
  HTTPException(this.message, this.response);
}
